@@ -20,13 +20,14 @@ from threading import Thread
 import zmq
 from jupyter_client.localinterfaces import localhost
 
+
 # -----------------------------------------------------------------------------
 # Code
 # -----------------------------------------------------------------------------
 
 
 class Heartbeat(Thread):
-    "A simple ping-pong style heartbeat that runs in a thread."
+    """A simple ping-pong style heartbeat that runs in a thread."""
 
     def __init__(self, context, addr=None):
         if addr is None:
@@ -52,7 +53,7 @@ class Heartbeat(Thread):
             s.close()
         elif self.transport == "ipc":
             self.port = 1
-            while os.path.exists("%s-%s" % (self.ip, self.port)):
+            while os.path.exists(f"{self.ip}-{self.port}"):
                 self.port = self.port + 1
         else:
             raise ValueError("Unrecognized zmq transport: %s" % self.transport)
@@ -60,7 +61,7 @@ class Heartbeat(Thread):
 
     def _try_bind_socket(self):
         c = ":" if self.transport == "tcp" else "-"
-        return self.socket.bind("%s://%s" % (self.transport, self.ip) + c + str(self.port))
+        return self.socket.bind(f"{self.transport}://{self.ip}" + c + str(self.port))
 
     def _bind_socket(self):
         try:
